# Configuration file

config.json - configuration file.

* To connect to a peer, you need to set an address (`peer.testnet.eontechnology.org:9443` for network TestNet, `peer.eontechnology.org:9443` for network MainNet)
  * `"peer": "peer.testnet.eontechnology.org:9443"`

* Seed for the account on behalf of which we will sign transactions (you can generate it in the command line by executing `openssl rand -hex 32`)
  * `"seed": "<your seed>"`

* Transaction’s secondary fields are needed to manage the commission (microEONs) and the transaction lifetime (minutes)
  * `"fee": 10`
  * `"deadline": 60`

* You can also specify a file to log the last transaction record that was sent to the server
  * `"last_tr_log": "<file_name>"`

    In case when not provided, a transaction will not be logged. Each transaction that is sent in JSON format will be displayed on the screen.

# Alias file

alias.json - alias file.

File contains key-value data witch represents alias names for colored coins.

Format: "colored coin ID": "alias name".

Example:
{
    "EON-C-QB3PM-Y3MRM-28TFL": "XXX",
    ...
    "EON-C-E4UYQ-6BBKZ-WVKLU": "YYY"
}

# Commands description

Commands for sending a new transaction: deposit, payment, register, delegate, rejection, quorum, sign, publication, emission, c-payment, re-emission, de-emission.

Commands for displaying information: history, attributes, seed, state, info, balance.

## List of available commands

### Getting or displaying information

* `attributes` - Shows attributes of the current peer
* `state` - Shows an account state in EONs and colored coins
* `history` - Shows the transactions history
* `info` - Shows an account EON ID and a public key
* `seed` - Generates SEED for a new account or shows an EON ID and a public key for an existing account
* `balance` - Shows an account balance in EONs and colored coins

### Using multi-signature

* `delegate` - Delegates X% of the digital signature to the specified account
* `rejection` - Reverts the delegation
* `quorum` - Sets the quorum for different types of transactions
* `publication` - Makes an account public (account SEED publication)

### Sending common transactions

* `register` - Creates a new network account using its public key
* `deposit` - Sets the deposit funds to participate in the generation of blocks
* `payment` - Transfers/Sends coins to another account
* `sign` - Signs the transaction

### Colored coins

* `emission` - Produces the colored coins
* `c-payment` - Makes a payment with colored coins
* `re-emission` - Changes the money supply of the colored coins
* `de-emission` - Deletes the colored coins

## Command usage

Usage: `./eon [<global args>] <command> [<args>]`

* To display "Help", use: `./eon help`
* To display help for global arguments, use: `./eon -h`
* To display help for specified command, use: `./eon <command> -h`

Global parameters can re-define values specified in the config file.

> `./eon -h`

```
Usage of ./eon:
  -D int
        Deadline (default 60)
  -F int
        Fee (default 10)
  -O string
        Output of transaction to a log-file (default "last_transaction.log")
  -P string
        Peer (default "peer.testnet.eontechnology.org:9443")
  -S string
        SEED (default "")
  -T    Trace HTTP requests
  -W    Only write a transaction to a log-file without send
```

# Transaction Types

The following transaction types are available:

* 100 - A new account registration - `./eon register`
* 200 - A coin transfer between two accounts - `./eon payment`
* 300 - Deposit funds to participate in the generation of blocks - `./eon deposit`

The MSM transaction types list:

* 400 - Sets the weight of the voice for the signature - `./eon delegate`
* 410 - Sets the quorum for different types of transactions - `./eon quorum`
* 420 - Refusal to participate in transaction confirmation - `./eon rejection`
* 430 - Allows to use an account in the public mode - `./eon publication`

The colored coin transaction types list:

* 500 - Produces the colored coins - `./eon emission`
* 510 - Makes a payment with colored coins - `./eon c-payment`
* 520 - Changes the money supply of the colored coins - `./eon re-emission`
* 530 - Removes all emitted colored coins (must all be on the issuer' balance) - `./eon de-emission`

# Getting or Displaying Information

## `attributes` - shows attributes of the current peer

> `./eon attributes`

```
Answer on get network attributes

Announced address of the peer: 127.0.0.1:9443
Application: EON (version 0.13.10-MAINNET)
Network ID: EON-B-2LVXG-F7DT2-SSWYS (fork 6)
Peer contains full blockchain history from this block height: 0
Peer ID: 7165054255307330892

end...
```

## `state` - shows an account state in EONs and colored coins

The current user account from the configuration file (by specified seed) will be used by default.

> `./eon state -h`

```
Usage of state command:
  -r string
        Recipient.
```

Usage

> `./eon state`

or

> `./eon state -r <account EON ID>`

```
Answer on get state for  EON-E4UYQ-6BBKZ-WVKLU

Balance (EON): 94.999980   Deposit: 5.000000
Emitted colored coins: 50.000 (EON-C-E4UYQ-6BBKZ-WVKLU)   Auto-mode: false
Account state: 200 - OK
Public key:    bf11909a1dbf27a116a19bc3ad918d2bb642f55d330441594c093b2d3bbfbd41Usage
Sign type:     normal

end...
```

You can check any network account state with its EON ID.

## `history` - shows the transactions history

You can view transactions sent and signed by a certain subscriber.
You can check which of them have already entered the blockchain and which ones have not.
If you do not input EON ID, the command will display information for the account from the configuration file.

> `./eon history -h`

```
Usage of history command:
  -a    All committed transactions.
  -b    All blocks generated by the account.
  -p int
        Page number (for committed transactions). (default 1)
  -r string
        Recipient.
  -u    Uncommitted transactions (that are not in the blockchain).
```

Usage:

> `./eon history`

```
Answer on get committed transactions page for EON-E4UYQ-6BBKZ-WVKLU, page 1

2018-09-03 14:42:56 C-Payment   | From:EON-QB3PM-Y3MRM-28TFL Fee:0.000010                             Note:C-payment
EON-T-2L9US-FPMCY-74B8P         | EON-QB3PM-Y3MRM-28TFL -> EON-E4UYQ-6BBKZ-WVKLU           1.00000 (EON-C-QB3PM-Y3MRM-28TFL)

2018-09-03 14:41:20 Delegate    | From:EON-E4UYQ-6BBKZ-WVKLU Fee:0.000010                             Note:Delegate
EON-T-2H9US-FPFL5-DU9CQ         | Delegate:  0% to EON-E4UYQ-6BBKZ-WVKLU

2018-09-03 14:38:28 Delegate    | From:EON-E4UYQ-6BBKZ-WVKLU Fee:0.000010                             Note:Delegate
EON-T-NB9US-FXVLU-BNHKP         | Delegate:100% to EON-QB3PM-Y3MRM-28TFL

2018-09-03 14:32:23 Rejection   | From:EON-E4UYQ-6BBKZ-WVKLU Fee:0.000010                             Note:Rejection
EON-T-9Y8US-FKHER-9BN5W         | Rejection from:EON-QB3PM-Y3MRM-28TFL

2018-09-03 14:09:37 C-Payment   | From:EON-QB3PM-Y3MRM-28TFL Fee:0.000010                             Note:C-payment
EON-T-KM7US-FKZQM-WNJDY         | EON-QB3PM-Y3MRM-28TFL -> EON-E4UYQ-6BBKZ-WVKLU           1.00000 (EON-C-QB3PM-Y3MRM-28TFL)

2018-09-03 12:25:29 Delegate    | From:EON-QB3PM-Y3MRM-28TFL Fee:0.000010                             Note:Delegate
EON-T-BJZTS-FBDMX-5BLUX         | Delegate: 30% to EON-E4UYQ-6BBKZ-WVKLU

2018-09-03 12:05:38 De-Emission | From:EON-E4UYQ-6BBKZ-WVKLU Fee:0.000010                             Note:De-emission
EON-T-4DYTS-FXRGX-LMQ3M         | Coins:EON-C-E4UYQ-6BBKZ-WVKLU

2018-09-03 12:02:54 Re-Emission | From:EON-E4UYQ-6BBKZ-WVKLU Fee:0.000010                             Note:Re-emission
EON-T-Y7YTS-FPF2U-5BRNR         | New coins:auto RAW(EON-C-E4UYQ-6BBKZ-WVKLU)

2018-09-03 11:35:42 Emission    | From:EON-E4UYQ-6BBKZ-WVKLU Fee:0.000010                             Note:Emission
EON-T-YLWTS-FTMGJ-97T3J         | New coins:50.000 (EON-C-E4UYQ-6BBKZ-WVKLU) Decimal places:3

2018-09-03 11:11:58 Deposit     | From:EON-E4UYQ-6BBKZ-WVKLU Fee:0.000010                             Note:Deposit
EON-T-G8VTS-FKLEF-LPR4W         | Deposit setting:                                        5.000000 (EON)

2018-09-03 11:08:41 Payment     | From:EON-QB3PM-Y3MRM-28TFL Fee:0.000010                             Note:Payment
EON-T-B2VTS-FXSCZ-NGYMY         | EON-QB3PM-Y3MRM-28TFL -> EON-E4UYQ-6BBKZ-WVKLU        100.000000 (EON)

2018-09-03 10:26:27 Register    | From:EON-QB3PM-Y3MRM-28TFL Fee:0.000010                             Note:Register
EON-T-5KSTS-FBVZM-M7C8N         | New account:EON-E4UYQ-6BBKZ-WVKLU Created by:EON-QB3PM-Y3MRM-28TFL


end...
```

## `info` - shows an account EON ID and a public key

With this command you can see information on the current account. By specifying a SEED value you can see corresponding public key.

> `./eon info -h`

```
Usage of info command:
  -s string
        SEED.
```

Usage:

> `./eon info`

or

> `./eon info -s <account SEED>`

```

Output:

EON account from seed
Account: EON-QB3PM-Y3MRM-28TFL
Public key: a0bbb80d11d6c60ad6807d344cf49c71aa317ed54f4b57da403e664fafdf63f2

end...
```

## `seed` - generates SEED for a new account or shows an EON ID and a public key for an existing account

A string of random symbols is created and on its bases EON ID and public key are figured out.

> `./eon seed -h`

```
Usage of seed command:
  -s string
        SEED.
```

Usage:

> `./eon seed`

or

> `./eon seed -s <account SEED>`

```
Generate seed for EON account
     Seed:  151f9b9860e8ce037d0533f83ae1a23b5b67cb4870f0224afbc5807d64ac1d4f
     Account:  EON-E4UYQ-6BBKZ-WVKLU
     Public key:  bf11909a1dbf27a116a19bc3ad918d2bb642f55d330441594c093b2d3bbfbd41

end...
```

## `balance` - shows an account balance in EONs and colored coins

The original command "state" shows the balance only in EONs.

> `./eon balance -h`

```
Usage of balance command:
  -r string
        Recipient.
```

Usage:

> `./eon balance`

```
Answer on get balance for  EON-E4UYQ-6BBKZ-WVKLU
State: 200 - OK
Balance:
  EON: 94.999980
  EON-C-E4UYQ-6BBKZ-WVKLU: 50.000

end...
```

# Sending common transactions

## `register` - creates a new network account using its public key

Once registered, you can create additional accounts on your behalf.
The public key for the new account is set in the account creation function parameters.

> `./eon register -h`

```
Usage of register command:
  -fp string
        Fee payer (EON ID).
  -k string
        Public key (required).
  -n string
        Note.
```

Usage:

> `./eon register -k bf11909a1dbf27a116a19bc3ad918d2bb642f55d330441594c093b2d3bbfbd41 -n "Register"`

```
Create a new EON account
     New account:  EON-E4UYQ-6BBKZ-WVKLU
     Public key for account:  bf11909a1dbf27a116a19bc3ad918d2bb642f55d330441594c093b2d3bbfbd41
     Note:  Register

Sending transaction:
{"version":1,"type":100,"timestamp":1535959587,"deadline":3600,"fee":10,"sender":"EON-QB3PM-Y3MRM-28TFL","signature":"17e9dd851607fa07b16233395bfda23e92b26115f4c97b0f0dae5427d2d58f3f3cc26ae35215b9d73c41edc2f7e579e1288d9a90244cc4fba0d0a7c3daf9a002","attachment":{"EON-E4UYQ-6BBKZ-WVKLU":"bf11909a1dbf27a116a19bc3ad918d2bb642f55d330441594c093b2d3bbfbd41"},"id":"EON-T-5KSTS-FBVZM-M7C8N","note":"Register"}

sending transaction (EON-T-5KSTS-FBVZM-M7C8N), answer ... success
end...
```

## `deposit` - sets the deposit funds to participate in the generation of blocks

> `./eon deposit -h`

```
Usage of deposit command:
  -a string
        Deposit amount (required).
  -fp string
        Fee payer (EON ID).
  -n string
        Note.
```

Usage:

> `./eon deposit -a 5 -n "Deposit"`

```
Setting the deposit funds to participate in the generation of blocks
     Amount: 5.000000
     Note:  Deposit

Sending transaction:
{"version":1,"type":300,"timestamp":1535962318,"deadline":3600,"fee":10,"sender":"EON-E4UYQ-6BBKZ-WVKLU","signature":"88bfdc9d151708074ad60a74c095bed0e741892b92a45a34d5f25ec793547e99f3f6762e4da3d5c49e34af0feb2260b4e395c4c17df3db5277800745ad6e210c","attachment":{"amount":5000000},"id":"EON-T-G8VTS-FKLEF-LPR4W","note":"Deposit"}

sending transaction (EON-T-G8VTS-FKLEF-LPR4W), answer ... success
end...
```

## `payment` - transfers/sends coins to another account

> `./eon payment -h`

```
Usage of payment command:
  -a string
        Amount (required).
  -fp string
        Fee payer (EON ID).
  -n string
        Note.
  -r string
        Recipient (required).
```

Usage:

> `./eon payment -a 100 -r EON-E4UYQ-6BBKZ-WVKLU -n "Payment"`

```
Transfer of coins between two accounts
     to EON account: EON-E4UYQ-6BBKZ-WVKLU
     Amount: 100.000000
     Note:  Payment

Sending transaction:
{"version":1,"type":200,"timestamp":1535962121,"deadline":3600,"fee":10,"sender":"EON-QB3PM-Y3MRM-28TFL","signature":"34cb369901a982a518b6ae5c9f9ee421bd671175c0a745dd4b3cf8a31136e3ebb6e6f8c69921ad137573c9b95a752af105c16f3f9d7afdf4bd12c2989a71ae0a","attachment":{"amount":100000000,"recipient":"EON-E4UYQ-6BBKZ-WVKLU"},"id":"EON-T-B2VTS-FXSCZ-NGYMY","note":"Payment"}

sending transaction (EON-T-B2VTS-FXSCZ-NGYMY), answer ... success
end...
```

## `sign` - signs the transaction

When MSM is active this command signs up a transaction taken from a file you specify. Once signed, such a transaction will be sent to the peer and the digital signature of the current user will be added.

> `./eon sign -h`

```
 Usage of sign command:
  -f string
        Transaction from file.
  -s string
        Transaction from string.
```

Usage:

> `./eon sign -f last_transaction.log`

Before signing:

```
{"version":1,"type":430,"timestamp":1536076354,"deadline":3600,"fee":10,"sender":"EON-E4UYQ-6BBKZ-WVKLU","signature":"ecbb092ac17c9b3d977b187fe94b5c2813a87a8f20aea0d2e4b65a19a1eac4dc95a172cceabb5e8793b5acea0b4f24543f2aca0cacac199b5cd3ad9d3be8280e","attachment":{"seed":"151f9b9860e8ce037d0533f83ae1a23b5b67cb4870f0224afbc5807d64ac1d4f"},"id":"EON-T-4LCXS-FBBWQ-U6YSW"}
```

After signing:

```
Transaction signed by EON-QB3PM-Y3MRM-28TFL

Sending transaction:
{"version":1,"type":430,"timestamp":1536076354,"deadline":3600,"fee":10,"sender":"EON-E4UYQ-6BBKZ-WVKLU","signature":"ecbb092ac17c9b3d977b187fe94b5c2813a87a8f20aea0d2e4b65a19a1eac4dc95a172cceabb5e8793b5acea0b4f24543f2aca0cacac199b5cd3ad9d3be8280e","attachment":{"seed":"151f9b9860e8ce037d0533f83ae1a23b5b67cb4870f0224afbc5807d64ac1d4f"},"confirmations":{"EON-QB3PM-Y3MRM-28TFL":"a16813852121657a2c1c4b42f52271528c98ea6699309dca294d8a78653345eea00b77d2e4839a9e0a6e34f900848a091ea7614c68fb2f3f312eb578298fc903"},"id":"EON-T-4LCXS-FBBWQ-U6YSW"}

sending transaction (EON-T-4LCXS-FBBWQ-U6YSW), answer ... success
end...
```

# Using Multi-Signature

## `delegate` - delegates X percents of the digital signature to the specified account

> `./eon delegate -h`

```
Usage of delegate command:
  -fp string
        Fee payer (EON ID).
  -n string
        Note.
  -p int
        Percentage of the digital signature (required). (default -1)
  -r string
        Recipient (required).
```

Usage:

> `./eon delegate -r EON-E4UYQ-6BBKZ-WVKLU -p 30 -n "Delegate"`

```
Delegate a voice
     Account:  EON-E4UYQ-6BBKZ-WVKLU
     Weight of voice:  30
     Note:  Delegate

Sending transaction:
{"version":1,"type":400,"timestamp":1535966729,"deadline":3600,"fee":10,"sender":"EON-QB3PM-Y3MRM-28TFL","signature":"3b7c3ad528219391db1ce17e6736a5c197cbfb174c0eb4fa18be03151e2a90d7b738c1f29f3799666cc53e1a42540eb88c8f1676076dc327cc4634b2f1456801","attachment":{"EON-E4UYQ-6BBKZ-WVKLU":30},"id":"EON-T-BJZTS-FBDMX-5BLUX","note":"Delegate"}

sending transaction (EON-T-BJZTS-FBDMX-5BLUX), answer ... success
end...
```

## `rejection` - reverts the delegation

> `./eon rejection -h`

```
Usage of rejection command:
  -fp string
        Fee payer (EON ID).
  -n string
        Note.
  -r string
        Recipient (required).
```

Usage:

> `./eon rejection -r EON-QB3PM-Y3MRM-28TFL -n "Rejection"`

```
Reject a voice
     Account:  EON-QB3PM-Y3MRM-28TFL
     Note:  Rejection

Sending transaction:
{"version":1,"type":420,"timestamp":1535974343,"deadline":3600,"fee":10,"sender":"EON-E4UYQ-6BBKZ-WVKLU","signature":"4d2079379b2b36c74a981d037fba5e5d1dd8b6d96a6d7a4ca165b5fc16ae8077f1fbc204f9eedd28c0ddd064e95c79f4021c1632c28eb744a78b804c04321603","attachment":{"account":"EON-QB3PM-Y3MRM-28TFL"},"id":"EON-T-9Y8US-FKHER-9BN5W","note":"Rejection"}

sending transaction (EON-T-9Y8US-FKHER-9BN5W), answer ... success
end...
```

## `quorum` - sets the quorum for different types of transactions

> `./eon quorum -h`

```
Usage of quorum command:
  -100 int
        Quorum for "register". (default -1)
  -200 int
        Quorum for "payment". (default -1)
  -300 int
        Quorum for "deposit". (default -1)
  -400 int
        Quorum for "delegate". (default -1)
  -410 int
        Quorum for "quorum". (default -1)
  -420 int
        Quorum for "rejection". (default -1)
  -430 int
        Quorum for "publication". (default -1)
  -500 int
        Quorum for "emission". (default -1)
  -510 int
        Quorum for "c-payment". (default -1)
  -520 int
        Quorum for "re-emission". (default -1)
  -530 int
        Quorum for "de-emission". (default -1)
  -600 int
        Quorum for "complex". (default -1)
  -all int
        Quorum for all types (required). (default -1)
  -fp string
        Fee payer (EON ID).
  -n string
        Note.
```

Usage:

> `./eon quorum -all 100 -510 80 -n "Quorum"`

```
Set a quorum
     Note:  Quorum
     all:  100
     510:  80

Sending transaction:
{"version":1,"type":410,"timestamp":1535966535,"deadline":3600,"fee":10,"sender":"EON-QB3PM-Y3MRM-28TFL","signature":"fb29995089cdac6ac80b3054f0d4f6bac8b60f0bfe43707c9baff71e750b6acbaae77b010aa9044549314626856b6b0d539375b642afbc53379f74da6880dd0b","attachment":{"510":80,"all":100},"id":"EON-T-9CZTS-FKW8Q-JVJMR","note":"Quorum"}

sending transaction (EON-T-9CZTS-FKW8Q-JVJMR), answer ... success
end...
```

## `publication` - makes an account public (account SEED publication)

To make an account public you should:

1. Withdraw rights of signature of all other accounts.
2. Specify signature “percentage” as 0% for the account which is made public (it means withdrawal of the right to sign).
3. Wait 24 hours after applying last change in delegation of a right to sign.
4. Publish account seed.

> `./eon publication -h`

```
Usage of publication command:
  -fp string
        Fee payer (EON ID).
  -n string
        Note.
```

### Step 1. Creating a new transaction

> `./eon publication`

```
Account publication
     Seed:  151f9b9860e8ce037d0533f83ae1a23b5b67cb4870f0224afbc5807d64ac1d4f

Sending transaction:
{"version":1,"type":430,"timestamp":1536076354,"deadline":3600,"fee":10,"sender":"EON-E4UYQ-6BBKZ-WVKLU","signature":"ecbb092ac17c9b3d977b187fe94b5c2813a87a8f20aea0d2e4b65a19a1eac4dc95a172cceabb5e8793b5acea0b4f24543f2aca0cacac199b5cd3ad9d3be8280e","attachment":{"seed":"151f9b9860e8ce037d0533f83ae1a23b5b67cb4870f0224afbc5807d64ac1d4f"},"id":"EON-T-4LCXS-FBBWQ-U6YSW"}

Failed send transaction (EON-T-4LCXS-FBBWQ-U6YSW): The quorum is not exist.

end...
```

### Step 2. Signing up and sending a transaction

> `./eon sign -f last_transaction.log`

```
Transaction signed by EON-QB3PM-Y3MRM-28TFL

Sending transaction:
{"version":1,"type":430,"timestamp":1536076354,"deadline":3600,"fee":10,"sender":"EON-E4UYQ-6BBKZ-WVKLU","signature":"ecbb092ac17c9b3d977b187fe94b5c2813a87a8f20aea0d2e4b65a19a1eac4dc95a172cceabb5e8793b5acea0b4f24543f2aca0cacac199b5cd3ad9d3be8280e","attachment":{"seed":"151f9b9860e8ce037d0533f83ae1a23b5b67cb4870f0224afbc5807d64ac1d4f"},"confirmations":{"EON-QB3PM-Y3MRM-28TFL":"a16813852121657a2c1c4b42f52271528c98ea6699309dca294d8a78653345eea00b77d2e4839a9e0a6e34f900848a091ea7614c68fb2f3f312eb578298fc903"},"id":"EON-T-4LCXS-FBBWQ-U6YSW"}

sending transaction (EON-T-4LCXS-FBBWQ-U6YSW), answer ... success
end...
```

### Step 3. Wait until a new transaction is confirmed

Please, bear in mind that once performed, the publication command cannot be reverted.

# Colored coins

## `emission` - produces the colored coins

This command produces the colored coin. The current account appoints as a creator. The type of colored coin is formed from the ID of the account. For example EON-QB3PM-Y3MRM-28TFL => EON-C-QB3PM-Y3MRM-28TFL.

* One account can produce only one type of colored coins.
* The maximum number cannot exceed 2^63-1 (9223372036854775807).

> `./eon emission -h`

```
Usage of emission command:
  -d int
        Decimal places (required). (default -1)
  -e string
        Emission of the new coins or "auto" (required).
  -fp string
        Fee payer (EON ID).
  -n string
        Note.
```

Usage:

> `./eon emission -e 50 -d 3 -n "Emission"`

```
Create new colored coins
     Total number of the colored coins (emission):  50.000
     The number of decimal places:  3
     Note:  Emission

Sending transaction:
{"version":1,"type":500,"timestamp":1535963742,"deadline":3600,"fee":10,"sender":"EON-E4UYQ-6BBKZ-WVKLU","signature":"141f6f7896f34fdb5d6a40ae288291fff26731aa65dcc668be5a83c637403977f6e5eb6e3ce22f49694ca194d746d84382cf158d50caf12a2e1dfbf47025e90c","attachment":{"decimal":3,"emission":50000},"id":"EON-T-YLWTS-FTMGJ-97T3J","note":"Emission"}

sending transaction (EON-T-YLWTS-FTMGJ-97T3J), answer ... success
end...
```

## `c-payment` - makes a payment with colored coins

This command is similar to the command "payment".

> `./eon c-payment -h`

```
Usage of c-payment command:
  -a string
        Amount (required).
  -fp string
        Fee payer (EON ID).
  -n string
        Note.
  -r string
        Recipient (required).
  -t string
        Type of coins (required).
```

Usage:

> `./eon c-payment -a 1 -r EON-E4UYQ-6BBKZ-WVKLU -t EON-C-QB3PM-Y3MRM-28TFL -n "C-payment"`

```
Transfer of the colored coins between two accounts
     to EON account: EON-E4UYQ-6BBKZ-WVKLU
     Amount: 1.00000
     Type of the colored coins: EON-C-QB3PM-Y3MRM-28TFL
     Note:  C-payment

Sending transaction:
{"version":1,"type":510,"timestamp":1535974976,"deadline":3600,"fee":10,"sender":"EON-QB3PM-Y3MRM-28TFL","signature":"f858fa9bc5c84139d4b2bacd0f0dd99b8208188ab008fed0f29087888200e505b84f6d398923183471cece8e1756ae0024129049073b557bfe0be0e01e1f920a","attachment":{"amount":100000,"color":"EON-C-QB3PM-Y3MRM-28TFL","recipient":"EON-E4UYQ-6BBKZ-WVKLU"},"id":"EON-T-2L9US-FPMCY-74B8P","note":"C-payment"}

sending transaction (EON-T-2L9US-FPMCY-74B8P), answer ... success
end...
```

## `re-emission` - changes the money supply of the colored coins

The operation which changes the money supply of the colored coins.
The inputted number parse according the rule which was set during the initiation of the colored coin. For example, the initial weight of c-coin was “123.000”. You want to increase it to “125.000”. You can input "125.0". It will be parsed as 125000.
If you want to reduce the weight of colored coins to 122, you must input ./eon re-emission -e 122. Withdrawn coins will be transferred from your amount.
For removing colored coins you must use the command `./eon de-emission`.

> `./eon re-emission -h`

```
Usage of re-emission command:
  -e string
        New emission or "auto" (required).
  -fp string
        Fee payer (EON ID).
  -n string
        Note.
```

Usage:

> `./eon re-emission -e auto -n "Re-emission"`

```
Change of the total number of the colored coins (emission)
     New total number of colored coins (emission):  auto
     Note:  Re-emission

Sending transaction:
{"version":1,"type":520,"timestamp":1535965374,"deadline":3600,"fee":10,"sender":"EON-E4UYQ-6BBKZ-WVKLU","signature":"7585e15241c97cfd4031469008420340c1e27bf83c23f312567135fbcb172a3989c0bbc70157eb1169f3e09b9d5198af1738bfc1819ad36f223dc886a5d9600e","attachment":{"supply":"auto"},"id":"EON-T-Y7YTS-FPF2U-5BRNR","note":"Re-emission"}

sending transaction (EON-T-Y7YTS-FPF2U-5BRNR), answer ... success
end...
```

## `de-emission` - deletes the colored coins

All issued colored coins must be on the creator's balance.

> `./eon de-emission -h`

```
Usage of de-emission command:
  -fp string
        Fee payer (EON ID).
  -n string
        Note.
```

Usage:

> `./eon de-emission -n "De-emission"`

```
Delete the colored coins
     Type of the colored coins: EON-C-E4UYQ-6BBKZ-WVKLU
     Note:  De-emission

Sending transaction:
{"version":1,"type":530,"timestamp":1535965538,"deadline":3600,"fee":10,"sender":"EON-E4UYQ-6BBKZ-WVKLU","signature":"a2ab7218d67c2d49970b3126bd40aaa1be6f929b002e73376d5db50074ec8fb76d981d8feefd2365c40045ab6c28ab458a6e7da96e6f4876037311d32f07ce0e","attachment":{},"id":"EON-T-4DYTS-FXRGX-LMQ3M","note":"De-emission"}

sending transaction (EON-T-4DYTS-FXRGX-LMQ3M), answer ... success
end...
```
